@@ -3,6 +3,7 @@
 """
 from .abf import Abf
 from .brainvision import BrainVision, write_brainvision, _write_vmrk
+from .eeglab import EEGLAB
 from .edf import Edf, write_edf
 from .ktlx import Ktlx
 from .blackrock import BlackRock
@@ -15,4 +16,4 @@ from .wonambi import Wonambi, write_wonambi
 from .micromed import Micromed
 from .bci2000 import BCI2000
 from .text import Text
-from .bids import BIDS
+from .bids import BIDS, write_bids
