@@ -5,7 +5,7 @@ from functools import partial
 from logging import getLogger
 from re import compile
 
-from numpy import (abs, arange, argmin, around, asarray, ceil, empty, floor,
+from numpy import (abs, amax, arange, argmin, around, asarray, ceil, empty, floor,
                    in1d, max, min, linspace, log2, logical_or, nan_to_num,
                    nanmean, pad, power)
 
@@ -27,6 +27,7 @@ from PyQt5.QtWidgets import (QAction,
                              QGraphicsView,
                              QGroupBox,
                              QInputDialog,
+                             QMessageBox,
                              QVBoxLayout,
                              )
 
@@ -193,6 +194,7 @@ class Traces(QGraphicsView):
         self.cross_chan_mrk = True
         self.highlight = None
         self.event_sel = None
+        self.current_event_row = None
         self.deselect = None
         self.ready = True
 
@@ -283,6 +285,26 @@ class Traces(QGraphicsView):
         act.triggered.connect(partial(self.add_time, 6 * 60 * 60))
         actions['addtime_6h'] = act
 
+        act = QAction('Go to next event', self)
+        act.setShortcut('s')
+        act.triggered.connect(self.next_event)
+        actions['next_event'] = act
+        
+        act = QAction('Delete event and go to next', self)
+        act.setShortcut('d')
+        act.triggered.connect(partial(self.next_event, True))
+        actions['del_and_next_event'] = act
+        
+        act = QAction('Next event of same type', self)
+        act.setCheckable(True)
+        act.setChecked(True)
+        actions['next_of_same_type'] = act
+        
+        act = QAction('Centre window around event', self)
+        act.setCheckable(True)
+        act.setChecked(True)
+        actions['centre_event'] = act
+        
         act = QAction('Full-length markers', self)
         act.setCheckable(True)
         act.setChecked(True)
@@ -588,8 +610,10 @@ class Traces(QGraphicsView):
                     item.setRotation(-90)
                     self.scene.addItem(item)
                     self.idx_annot_labels.append(item)
+                    mrk_dur = amax((mrk_end - mrk_start, 
+                                  self.parent.value('min_marker_display_dur')))
 
-                    item = RectMarker(mrk_start, 0, mrk_end - mrk_start,
+                    item = RectMarker(mrk_start, 0, mrk_dur,
                                       h_annot, zvalue=-8,
                                       color=color.lighter(120))
 
@@ -601,9 +625,11 @@ class Traces(QGraphicsView):
                     chan_idx_in_mrk = in1d(self.chan, annot['chan'])
                     y_annot = asarray(self.chan_pos)[chan_idx_in_mrk]
                     y_annot -= y_distance / 2
+                    mrk_dur = amax((mrk_end - mrk_start, 
+                                  self.parent.value('min_marker_display_dur')))
 
                     for y in y_annot:
-                        item = RectMarker(mrk_start, y, mrk_end - mrk_start,
+                        item = RectMarker(mrk_start, y, mrk_dur,
                                           y_distance, zvalue=-7, color=color)
                         self.scene.addItem(item)
                         self.idx_annot.append(item)
@@ -751,6 +777,7 @@ class Traces(QGraphicsView):
         if self.event_sel:
             self.deselect = True
             self.event_sel = None
+            self.current_event_row = None
             highlight = self.highlight
             self.scene.removeItem(highlight)
             self.highlight = None
@@ -776,50 +803,15 @@ class Traces(QGraphicsView):
         else:
             for annot in self.idx_annot:
                 if annot.contains(xy_scene):
-                    beg = annot.marker.x() - 0.5
-                    end = beg + annot.marker.width() + 1
-                    msg = 'Event from ' + str(beg) + ' to ' + str(end)
-                    self.parent.statusBar().showMessage(msg)
-                    self.event_sel = annot
-                    highlight = RectMarker(annot.marker.x(),
-                                           annot.marker.y(),
-                                           annot.marker.width(),
-                                           annot.marker.height(),
-                                           zvalue=-5,
-                                           color=QColor(255, 255, 51))
-#==============================================================================
-#                     pen = QPen(QColor(255, 255, 51), 0, Qt.SolidLine,
-#                                Qt.RoundCap)
-#                     brush = QBrush(QColor(255, 255, 51))
-#                     highlight.setPen(pen)
-#                     highlight.setBrush(brush)
-#                     highlight.setZValue(-5)
-#==============================================================================
-                    self.scene.addItem(highlight)
-                    self.highlight = highlight
+                    self.highlight_event(annot)
+                    row = self.parent.notes.find_row(annot.marker.x(),
+                                    annot.marker.x() + annot.marker.width())
+                    self.parent.notes.idx_annot_list.setCurrentCell(row, 0)
                     break
 
         # self.display_annotations
         self.ready = True
 
-        """
-    def mouseDoubleClickEvent(self, event):
-        When an event marker is double-clicked, it is removed
-        if not self.scene:
-            return
-
-        chk_marker = self.parent.notes.action['new_bookmark'].isChecked()
-        chk_event = self.parent.notes.action['new_event'].isChecked()
-
-        if not (chk_marker or chk_event):
-            xy_scene = self.mapToScene(event.pos())
-            for annot in self.idx_annot:
-                if annot.contains(xy_scene):
-                    self.parent.statusBar().showMessage('You clicked on an event!')
-                    self.parent.notes.remove_event(self, time=annot.mapToScene(0,0))
-                    self.scene.removeItem(annot)
-        """
-
     def mouseMoveEvent(self, event):
         """When normal selection, update power spectrum with current selection.
         Otherwise, show the range of the new marker.
@@ -971,7 +963,8 @@ class Traces(QGraphicsView):
             self.idx_sel = None
 
     def keyPressEvent(self, event):
-        if not self.event_sel:
+        chk_event = self.parent.notes.action['new_event'].isChecked()
+        if not (chk_event and self.event_sel):
             return
 
         annot = self.event_sel
@@ -989,6 +982,83 @@ class Traces(QGraphicsView):
             self.highlight = None
             self.display_annotations
 
+    def highlight_event(self, annot):
+        """Highlight an annotation on the trace.
+        
+        Parameters
+        ----------
+        annot : intance of wonambi.widgets.utils.RectMarker
+            existing annotation
+        """
+        beg = annot.marker.x()
+        end = beg + annot.marker.width()
+        msg = 'Event from ' + str(beg) + ' to ' + str(end)
+        self.parent.statusBar().showMessage(msg)
+        highlight = RectMarker(annot.marker.x(),
+                               annot.marker.y(),
+                               annot.marker.width(),
+                               annot.marker.height(),
+                               zvalue=-5,
+                               color=QColor(255, 255, 51))
+        self.scene.addItem(highlight)
+        self.highlight = highlight
+        self.event_sel = annot
+    
+    def next_event(self, delete=False):
+        """Go to next event."""
+        if delete:
+            msg = "Delete this event? This cannot be undone."
+            msgbox = QMessageBox(QMessageBox.Question, 'Delete event', msg)
+            msgbox.setStandardButtons(QMessageBox.Yes | QMessageBox.No)
+            msgbox.setDefaultButton(QMessageBox.Yes)
+            response = msgbox.exec_()
+            if response == QMessageBox.No:
+                return
+        
+        event_sel = self.event_sel
+        if event_sel is None:
+            return
+        
+        notes = self.parent.notes
+        
+        if not self.current_event_row:
+            row = notes.find_row(event_sel.marker.x(),
+                            event_sel.marker.x() + event_sel.marker.width())
+        else:
+            row = self.current_event_row
+            
+        same_type = self.action['next_of_same_type'].isChecked()
+        if same_type:
+            target = notes.idx_annot_list.item(row, 2).text()
+        
+        if delete:            
+            notes.delete_row()
+            msg = 'Deleted event from {} to {}.'.format(event_sel.marker.x(), 
+                            event_sel.marker.x() + event_sel.marker.width())
+            self.parent.statusBar().showMessage(msg)
+            row -= 1
+        
+        if row + 1 == notes.idx_annot_list.rowCount():
+            return
+        
+        if not same_type:
+            next_row = row + 1
+        else:
+            next_row = None
+            types = notes.idx_annot_list.property('name')[row + 1:]
+            
+            for i, ty in enumerate(types):
+                if ty == target:
+                    next_row = row + 1 + i
+                    break
+                    
+            if next_row is None:
+                return                
+                    
+        self.current_event_row = next_row
+        notes.go_to_marker(next_row, 0, 'annot')
+        notes.idx_annot_list.setCurrentCell(next_row, 0)             
+    
     def resizeEvent(self, event):
         """Resize scene so that it fits the whole widget.
 
